@@ -29,8 +29,8 @@ class SyncKohaRowsCommand(BaseCommand):
                 records = cursor.fetchall()
 
                 # TODO normalize values
-                # lowecase
-                # , ; : / . (\s){2+}
+                    # lowecase
+                    # , ; : / . (\s){2+}
 
                 with tqdm(total=len(records), desc="SYNCHRONIZING ROWS") as progress_bar:
                     for record in records:
@@ -43,13 +43,12 @@ class SyncKohaRowsCommand(BaseCommand):
                 # pprint.pprint(records)
                 # exit()
 
-                url = "{base}/{path}".format(base=Config.config['target']['url_add'], path=self.add)
-
-                post_rows_req = requests.post(url, json={
-                    "llave": Config.config['target']['key'],
-                    "secreto": Config.config['target']['secret'],
-                    "docs": records
-                })
+                post_rows_req = requests.post(f"{Config.config['target']['url_add']}/{self.add}",
+                                              json={
+                                                  "llave": Config.config['target']['key'],
+                                                  "secreto": Config.config['target']['secret'],
+                                                  "docs": records
+                                              })
 
                 if post_rows_req.status_code is not 200:
                     logger.warning(f"Request status was not 200 : {vars(post_rows_req)}")
